@@ -250,7 +250,15 @@ class OAPDash(dash.Dash):
             #     srcs.append(static_url)
 
         body += "var renderer = new DashRenderer();\n"
-        body += f"var oapInStoreId = '{self.in_store_id}';"
+
+        app_service_base_url = os.getenv('APP_SERVICE_BASE_URL')
+        if os.getenv('ON_PROXY') == 'true':
+            app_service_base_url = 'https://localhost' + app_service_base_url[app_service_base_url.index('/oap-api'):]
+
+        oap_app_id = os.getenv('OAP_APP_ID')
+        body += f"var OAP_API_URL = '{app_service_base_url}';\n"
+        body += f"var OAP_APP_ID = '{oap_app_id}';\n"
+        body += f"var OAP_IN_STORE_ID = '{self.in_store_id}';\n"
 
         response = flask.Response(body, mimetype='application/javascript')
 
@@ -264,8 +272,6 @@ class OAPDash(dash.Dash):
         elif file_name == 'main.wrapper.js':
             static_media_path = f'{self.config.requests_pathname_prefix.lstrip("/")}wrapper-static/media/'
             txt_body = txt_body.replace('static/media/', static_media_path)
-            if os.getenv('ON_PROXY') == 'true':
-                txt_body = txt_body.replace('http://13.57.187.238:8001', 'https://localhost')
 
         return txt_body + "\n"
 
